@@ -25,16 +25,6 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 #include "Histogram.h"
 // #include "imageclasses/ImgUtils.h"
 
-#ifndef PI
-#define PI 3.1415926535897932384626433832795
-#endif
-
-#include <math.h>
-
-#ifndef DEG2RAD
-#define DEG2RAD(DEG) ((DEG)*((PI)/(180.0)))
-#endif
-
 Filter2d::Filter2d::Filter2d(void)
   : m_noValue(0)
 {
@@ -172,7 +162,7 @@ void Filter2d::Filter2d::filter(const ImgReaderGdal& input, ImgWriterGdal& outpu
 	  }
         }
         if(absolute)
-          outBuffer[x]=(normalize)? abs(outBuffer[x])/norm : abs(outBuffer[x]);
+          outBuffer[x]=(normalize&&norm)? abs(outBuffer[x])/norm : abs(outBuffer[x]);
         else if(normalize&&norm!=0)
           outBuffer[x]=outBuffer[x]/norm;
       }
@@ -418,24 +408,16 @@ void Filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output,
 
 void Filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output, int method, int dimX, int dimY, short down, bool disc)
 {
-  // ImgReaderGdal input;
-  // ImgWriterGdal output;
-  // input.open(inputFilename);
-  // output.open(outputFilename,input);
   assert(dimX);
   assert(dimY);
   Histogram hist;
   for(int iband=0;iband<input.nrOfBand();++iband){
     Vector2d<double> inBuffer(dimY,input.nrOfCol());
-    // vector<double> outBuffer(input.nrOfCol());
     vector<double> outBuffer((input.nrOfCol()+down-1)/down);
     //initialize last half of inBuffer
     int indexI=0;
     int indexJ=0;
-    // for(int y=0;y<dimY;++y){
     for(int j=-dimY/2;j<(dimY+1)/2;++j){
-      // if(y<dimY/2)
-      //   continue;//skip first half
       try{
         input.readData(inBuffer[indexJ],GDT_Float64,abs(j),iband);
       }
@@ -449,7 +431,6 @@ void Filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output,
     GDALProgressFunc pfnProgress=GDALTermProgress;
     double progress=0;
     pfnProgress(progress,pszMessage,pProgressArg);
-    // for(int y=0;y<input.nrOfRow();++y){
     for(int y=0;y<input.nrOfRow();++y){
       if(y){//inBuffer already initialized for y=0
 	//erase first line from inBuffer
@@ -478,7 +459,6 @@ void Filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output,
       for(int x=0;x<input.nrOfCol();++x){
         if((x+1+down/2)%down)
           continue;
-	// outBuffer[x]=0;
 	outBuffer[x/down]=0;
 	vector<double> windowBuffer;
 	map<int,int> occurrence;
@@ -493,24 +473,12 @@ void Filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output,
 	      indexI=-indexI;
 	    else if(indexI>=input.nrOfCol())
 	      indexI=input.nrOfCol()-i;
-	      // indexI=input.nrOfCol()-indexI;
 	    if(y+j<0)
 	      indexJ=-j;
 	    else if(y+j>=input.nrOfRow())
 	      indexJ=dimY/2-j;
 	    else
 	      indexJ=dimY/2+j;
-	    // if(method==HOMOG||method==DENSITY||method==MAJORITY||method==MIXED){
-	    //   bool masked=false;
-	    //   for(int imask=0;imask<m_mask.size();++imask){
-	    //     if(inBuffer[indexJ][indexI]==m_mask[imask]){
-	    //       masked=true;
-	    //       break;
-	    //     }
-	    //   }
-	    //   if(!masked)
-	    //     ++occurrence[inBuffer[indexJ][indexI]];
-	    // }
 	    bool masked=false;
 	    for(int imask=0;imask<m_mask.size();++imask){
 	      if(inBuffer[indexJ][indexI]==m_mask[imask]){
@@ -535,64 +503,82 @@ void Filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output,
         }
         switch(method){
         case(MEDIAN):
-          // outBuffer[x]=hist.median(windowBuffer);
           outBuffer[x/down]=hist.median(windowBuffer);
           break;
         case(VAR):{
-          // outBuffer[x]=hist.var(windowBuffer);
           outBuffer[x/down]=hist.var(windowBuffer);
           break;
         }
         case(MEAN):{
-          // outBuffer[x]=hist.mean(windowBuffer);
           outBuffer[x/down]=hist.mean(windowBuffer);
           break;
         }
         case(MIN):{
-          // outBuffer[x]=hist.min(windowBuffer);
           outBuffer[x/down]=hist.min(windowBuffer);
           break;
         }
+        case(ISMIN):{
+          outBuffer[x/down]=(hist.min(windowBuffer)==windowBuffer[dimX*dimY/2])? 1:0;
+          break;
+        }
         case(MINMAX):{
           double min=0;
           double max=0;
           hist.minmax(windowBuffer,windowBuffer.begin(),windowBuffer.end(),min,max);
           if(min!=max)
             outBuffer[x/down]=0;
-            // outBuffer[x]=0;
           else
             outBuffer[x/down]=windowBuffer[dimX*dimY/2];//centre pixels
-            // outBuffer[x]=windowBuffer[dimX*dimY/2];//centre pixels
           break;
         }
         case(MAX):{
-          // outBuffer[x]=hist.max(windowBuffer);
           outBuffer[x/down]=hist.max(windowBuffer);
           break;
         }
+        case(ISMAX):{
+          outBuffer[x/down]=(hist.max(windowBuffer)==windowBuffer[dimX*dimY/2])? 1:0;
+          break;
+        }
+        case(ORDER):{
+          double lbound=0;
+          double ubound=dimX*dimY;
+          double theMin=hist.min(windowBuffer);
+          double theMax=hist.max(windowBuffer);
+          double scale=(ubound-lbound)/(theMax-theMin);
+          outBuffer[x/down]=static_cast<short>(scale*(windowBuffer[dimX*dimY/2]-theMin)+lbound);
+          break;
+        }
         case(SUM):{
-          // outBuffer[x]=hist.sum(windowBuffer);
           outBuffer[x/down]=hist.sum(windowBuffer);
           break;
         }
         case(HOMOG):
 	  if(occurrence.size()==1)//all values in window must be the same
 	    outBuffer[x/down]=inBuffer[dimY/2][x];
-	    // outBuffer[x]=inBuffer[dimY/2][x];
 	  else//favorize original value in case of ties
 	    outBuffer[x/down]=m_noValue;
-	    // outBuffer[x]=m_noValue;
           break;
+        case(HETEROG):{
+          for(vector<double>::const_iterator wit=windowBuffer.begin();wit!=windowBuffer.end();++wit){
+            if(wit==windowBuffer.begin()+windowBuffer.size()/2)
+              continue;
+            else if(*wit!=inBuffer[dimY/2][x])
+              outBuffer[x/down]=1;
+            else if(*wit==inBuffer[dimY/2][x]){//todo:wit mag niet central pixel zijn
+              outBuffer[x/down]=m_noValue;
+              break;
+            }
+          }
+          break;
+        }
         case(DENSITY):{
 	  if(windowBuffer.size()){
 	    vector<short>::const_iterator vit=m_class.begin();
 	    while(vit!=m_class.end())
 	      outBuffer[x/down]+=100.0*occurrence[*(vit++)]/windowBuffer.size();
-	      // outBuffer[x]+=100.0*occurrence[*(vit++)]/windowBuffer.size();
 	  }
 	  else
 	    outBuffer[x/down]=0;
-	    // outBuffer[x]=0;
           break;
 	}
         case(MAJORITY):{
@@ -609,7 +595,6 @@ void Filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output,
 	  }
 	  else
 	    outBuffer[x/down]=0;
-          // outBuffer[x]=0;
           break;
         }
         case(THRESHOLD):{
@@ -650,32 +635,25 @@ void Filter2d::Filter2d::doit(const ImgReaderGdal& input, ImgWriterGdal& output,
           }
 	  else
 	    outBuffer[x/down]=inBuffer[indexJ][indexI];
-            // outBuffer[x]=0;
           break;
         }
         default:
           break;
         }
       }
-      // progress=(1.0+y);
       progress=(1.0+y/down);
       progress+=(output.nrOfRow()*iband);
       progress/=output.nrOfBand()*output.nrOfRow();
-      // assert(progress>=0);
-      // assert(progress<=1);
       pfnProgress(progress,pszMessage,pProgressArg);
       //write outBuffer to file
       try{
         output.writeData(outBuffer,GDT_Float64,y/down,iband);
-        // output.writeData(outBuffer,GDT_Float64,y,iband);
       }
       catch(string errorstring){
 	cerr << errorstring << "in band " << iband << ", line " << y << endl;
       }
     }
   }
-  // input.close();
-  // output.close();
 }
 
 //todo: re-implement without dependency of CImg and reg libraries
@@ -827,10 +805,11 @@ void Filter2d::Filter2d::morphology(const ImgReaderGdal& input, ImgWriterGdal& o
 	}
       }
       for(int x=0;x<input.nrOfCol();++x){
-	outBuffer[x]=0;
         double currentValue=inBuffer[dimY/2][x];
+	outBuffer[x]=currentValue;
 	vector<double> histBuffer;
 	bool currentMasked=false;
+        double rse=0;
 	for(int imask=0;imask<m_mask.size();++imask){
 	  if(currentValue==m_mask[imask]){
 	    currentMasked=true;
@@ -845,17 +824,44 @@ void Filter2d::Filter2d::morphology(const ImgReaderGdal& input, ImgWriterGdal& o
 	    for(int i=-dimX/2;i<(dimX+1)/2;++i){
 	      if(disc&&(i*i+j*j>(dimX/2)*(dimY/2)))
 		continue;
-	      // if(angle>=-180){
-	      // 	double theta;
-	      // 	if(i)
-	      // 	  theta=atan(static_cast<double>(j)/(static_cast<double>(i)));
-	      // 	else if(j>0)
-	      // 	  theta=PI/2.0;
-	      // 	else if(j<0)
-	      // 	  theta=3.0*PI/2.0;
-	      // 	if(j&&(theta<DEG2RAD(angle)||theta>DEG2RAD(angle+PI)))
-	      // 	  continue;
-	      // }
+              bool masked=false;
+	      if(angle>=-180){
+	      	// double theta;
+	      	// if(i>0)
+	      	//   theta=atan(static_cast<double>(j)/(static_cast<double>(i)));
+	      	// else if(i<0)
+	      	//   theta=PI+atan(static_cast<double>(j)/(static_cast<double>(i)));
+	      	// else if(j>0)
+	      	//   theta=PI/2.0;
+	      	// else if(j<0)
+	      	//   theta=3.0*PI/2.0;
+                // rse=sqrt((theta-DEG2RAD(angle))*(theta-DEG2RAD(angle))/theta/theta);
+                // //test
+                if(angle<45||angle>315)
+                  if((j!=0)||(i>0))//RIGHT
+                    continue;
+                if(angle>135&&angle<225)
+                  if(j!=0||i<0)//LEFT
+                    continue;
+                if(angle>45&&angle<135)
+                  if(j<0||i!=0)//UP
+                    continue;
+                if(angle>225&&angle<315)
+                  if(j>0||i!=0)//DOWN
+                    continue;
+                if(angle>270&&angle<360)
+                  if(j>0||i>0)//LOWER RIGHT
+                    continue;
+                if(angle>0&&angle<90)
+                  if(j<0||i>0)//UPPER RIGHT
+                    continue;
+                if(angle>180&&angle<270)
+                  if(j>0||i<0)//LOWER LEFT
+                    continue;
+                if(angle>90&&angle<180)
+                  if(j<0||i<0)//UPPER LEFT
+                    continue;
+	      }
 	      indexI=x+i;
 	      //check if out of bounds
 	      if(indexI<0)
@@ -868,7 +874,6 @@ void Filter2d::Filter2d::morphology(const ImgReaderGdal& input, ImgWriterGdal& o
 		indexJ=dimY/2-j;//indexJ=inBuffer.size()-1-j;
 	      else
 		indexJ=dimY/2+j;
-	      bool masked=false;
 	      for(int imask=0;imask<m_mask.size();++imask){
 		if(inBuffer[indexJ][indexI]==m_mask[imask]){
 		  masked=true;
@@ -889,27 +894,24 @@ void Filter2d::Filter2d::morphology(const ImgReaderGdal& input, ImgWriterGdal& o
 		  histBuffer.push_back(inBuffer[indexJ][indexI]);
 	      }
 	    }
-	  }
-	  assert(histBuffer.size());//should never occur if not masked (?)
-	  switch(method){
-	  case(DILATE):
-	    outBuffer[x]=hist.max(histBuffer);
-	    break;
-	  case(ERODE):
-	    outBuffer[x]=hist.min(histBuffer);
-	    break;
-	  default:
-	    ostringstream ess;
-	    ess << "Error:  morphology method " << method << " not supported, choose " << DILATE << " (dilate) or " << ERODE << " (erode)" << endl;
-	    throw(ess.str());
-	    break;
-	  }
+          }
+	  if(histBuffer.size()){
+            switch(method){
+            case(DILATE):
+              outBuffer[x]=hist.max(histBuffer);
+              break;
+            case(ERODE):
+              outBuffer[x]=hist.min(histBuffer);
+              break;
+            default:
+              ostringstream ess;
+              ess << "Error:  morphology method " << method << " not supported, choose " << DILATE << " (dilate) or " << ERODE << " (erode)" << endl;
+              throw(ess.str());
+              break;
+            }
+          }
 	  if(outBuffer[x]&&m_class.size())
 	    outBuffer[x]=m_class[0];
-	  // else{
-	  //   assert(m_mask.size());
-	  //   outBuffer[x]=m_mask[0];
-	  // }
 	}
       }
       //write outBuffer to file
@@ -926,3 +928,11 @@ void Filter2d::Filter2d::morphology(const ImgReaderGdal& input, ImgWriterGdal& o
     }
   }
 }
+
+void Filter2d::Filter2d::shadowDsm(const ImgReaderGdal& input, ImgWriterGdal& output, double sza, double saa, double pixelSize, short shadowFlag){
+  Vector2d<float> inputBuffer;
+  Vector2d<float> outputBuffer;
+  input.readDataBlock(inputBuffer, GDT_Float32, 0, input.nrOfCol()-1, 0, input.nrOfRow()-1, 0);
+  shadowDsm(inputBuffer, outputBuffer, sza, saa, pixelSize, shadowFlag);
+  output.writeDataBlock(outputBuffer,GDT_Float32,0,output.nrOfCol()-1,0,output.nrOfRow()-1,0);
+}
