@@ -21,6 +21,7 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 #include <string>
 #include <list>
 #include <iostream>
+#include <algorithm>
 #include "imageclasses/ImgWriterGdal.h"
 #include "imageclasses/ImgReaderGdal.h"
 #include "imageclasses/ImgReaderOgr.h"
@@ -57,10 +58,10 @@ int main(int argc, char *argv[])
   Optionpk<int>  band_opt("b", "band", "band index to crop (-1: crop all bands)", -1);
   Optionpk<double> scale_opt("s", "scale", "output=scale*input+offset", 1);
   Optionpk<double> offset_opt("off", "offset", "output=scale*input+offset", 0);
-  Optionpk<string>  otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image", "");
-  Optionpk<string>  oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image", "");
+  Optionpk<string>  otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image","");
+  Optionpk<string>  oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image");
   Optionpk<string>  colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid)", "");
-  Optionpk<string> option_opt("co", "co", "options: NAME=VALUE [-co COMPRESS=LZW] [-co INTERLEAVE=BAND]", "INTERLEAVE=BAND");
+  Optionpk<string> option_opt("co", "co", "options: NAME=VALUE [-co COMPRESS=LZW] [-co INTERLEAVE=BAND]");
   Optionpk<short>  flag_opt("f", "flag", "Flag value to put in image if out of bounds.", 0);
   Optionpk<string>  resample_opt("r", "resampling-method", "Resampling method (near: nearest neighbour, bilinear: bi-linear interpolation).", "near");
   Optionpk<string>  description_opt("d", "description", "Set image description", "");
@@ -183,6 +184,12 @@ int main(int argc, char *argv[])
   //determine number of output bands
   int ncropband=0;//total number of bands to write
   int writeBand=0;//write band
+
+  while(scale_opt.size()<band_opt.size())
+    scale_opt.push_back(scale_opt[0]);
+  while(offset_opt.size()<band_opt.size())
+    offset_opt.push_back(offset_opt[0]);
+
   for(int iimg=0;iimg<input_opt.size();++iimg){
     imgReader.open(input_opt[iimg]);
     if(band_opt[0]>=0)
@@ -201,6 +208,11 @@ int main(int argc, char *argv[])
       if(verbose_opt[0])
         cout << "Using data type from input image: " << GDALGetDataTypeName(theType) << endl;
     }
+    if(option_opt.findSubstring("INTERLEAVE=")==option_opt.end()){
+      string theInterleave="INTERLEAVE=";
+      theInterleave+=imgReader.getInterleave();
+      option_opt.push_back(theInterleave);
+    }
     int nrow=imgReader.nrOfRow();
     int ncol=imgReader.nrOfCol();
     int ncropcol=0;
@@ -296,7 +308,7 @@ int main(int argc, char *argv[])
       // else
       //   theInterleave=imgReader.getInterleave();
       string imageType=imgReader.getImageType();
-      if(oformat_opt[0]!="")//default
+      if(oformat_opt.size())//default
         imageType=oformat_opt[0];
       try{
         imgWriter.open(output_opt[0],ncropcol,ncroprow,ncropband,theType,imageType,option_opt);
@@ -338,8 +350,6 @@ int main(int argc, char *argv[])
     else if(lri>=imgReader.nrOfCol())
       endCol=imgReader.nrOfCol()-1;
     int readncol=endCol-startCol+1;
-    //test
-    // vector<double> readBuffer(readncol);
     vector<double> readBuffer(readncol+1);
     int nband=(band_opt[0]<0)?imgReader.nrOfBand():band_opt.size();
     for(int iband=0;iband<nband;++iband){
@@ -376,8 +386,6 @@ int main(int argc, char *argv[])
               imgReader.readData(readBuffer,GDT_Float64,startCol,endCol+1,readRow,readBand,theResample);
             else
               imgReader.readData(readBuffer,GDT_Float64,startCol,endCol,readRow,readBand,theResample);
-            //test
-	    // imgReader.readData(readBuffer,GDT_Float64,startCol,endCol,readRow,readBand,theResample);
 	    for(int ib=0;ib<ncropcol;++ib){
 	      assert(imgWriter.image2geo(ib,irow,x,y));
 	      //lookup corresponding row for irow in this file
@@ -419,6 +427,8 @@ int main(int argc, char *argv[])
                 if(!valid)
                   writeBuffer.push_back(flag_opt[0]);
                 else{
+                  double theScale=(scale_opt.size()>1)?scale_opt[iband]:scale_opt[0];
+                  double theOffset=(offset_opt.size()>1)?offset_opt[iband]:offset_opt[0];
                   switch(theResample){
                   case(BILINEAR):
                     lowerCol=readCol-0.5;
@@ -429,12 +439,12 @@ int main(int argc, char *argv[])
                       lowerCol=0;
                     if(upperCol>=imgReader.nrOfCol())
                       upperCol=imgReader.nrOfCol()-1;
-                    writeBuffer.push_back((readCol-0.5-lowerCol)*(readBuffer[upperCol-startCol]*scale_opt[0]+offset_opt[0])+(1-readCol+0.5+lowerCol)*(readBuffer[lowerCol-startCol]*scale_opt[0]+offset_opt[0]));
+                    writeBuffer.push_back((readCol-0.5-lowerCol)*(readBuffer[upperCol-startCol]*theScale+theOffset)+(1-readCol+0.5+lowerCol)*(readBuffer[lowerCol-startCol]*theScale+theOffset));
                     break;
                   default:
                     readCol=static_cast<int>(readCol);
                     readCol-=startCol;//we only start reading from startCol
-                    writeBuffer.push_back(readBuffer[readCol]*scale_opt[0]+offset_opt[0]);
+                    writeBuffer.push_back(readBuffer[readCol]*theScale+theOffset);
                     break;
                   }
                 }
